Module: SurfaceMaster::Logging
- Included in:
- Device, Interaction
- Defined in:
- lib/surface_master/logging.rb
Overview
This module provides logging facilities. Just include it to be able to log stuff.
Instance Method Summary collapse
-
#logger ⇒ Object
Returns the logger to be used by the current instance.
-
#logger=(logger) ⇒ Object
Sets the logger to be used by the current instance.
Instance Method Details
#logger ⇒ Object
Returns the logger to be used by the current instance.
Creates one if none was set.
8 9 10 |
# File 'lib/surface_master/logging.rb', line 8 def logger @logger ||= Logger.new(STDERR) end |
#logger=(logger) ⇒ Object
Sets the logger to be used by the current instance.
13 |
# File 'lib/surface_master/logging.rb', line 13 def logger=(logger); @logger = logger; end |